#pragma once
#ifndef PLAYER_ORBIT_GR_H
#define PLAYER_ORBIT_GR_H

#include "sgg/graphics.h"
#include <cmath>
#define M_PI 3.14159265358979323846

struct Player {
    float x, y;       // Θέση του κέντρου του παίκτη
    float radius;     // Ακτίνα του κύκλου που αναπαριστά τον παίκτη
    float speed;      // Ταχύτητα του παίκτη
    float angle;      // Κλίση σε μοίρες για τις βολές
    float time;       // Χρόνος για κίνηση βασισμένη στον χρόνο (ελεύθερη πτώση κτλ)
};

// Ομαλή ευθύγραμμη οριζόντια κίνηση
void moveHorizontal(Player& player, float speed) {
    player.x += speed;
}

// Ομαλή ευθύγραμμη κατακόρυφη κίνηση
void moveVertical(Player& player, float speed) {
    player.y += speed;
}

// Κυκλική κίνηση
void moveCircular(Player& player, float centerX, float centerY, float radius, float speed) {
    player.angle += speed;
    player.x = centerX + radius * cos(player.angle * M_PI / 180.0f);
    player.y = centerY + radius * sin(player.angle * M_PI / 180.0f);
}

// Ελεύθερη πτώση
void freeFall(Player& player, float gravity = 9.8f) {
    player.y += 0.5f * gravity * player.time * player.time;
    player.time += 0.1f; // Ενημέρωση του χρόνου σε κάθε καρέ
}

// Κάθετη προς τα πάνω βολή
void verticalThrow(Player& player, float initialVelocity, float gravity = 9.8f) {
    player.y -= initialVelocity * player.time - 0.5f * gravity * player.time * player.time;
    player.time += 0.1f;
}

// Βολή με κλίση
void inclinedThrow(Player& player, float initialVelocity, float angle, float gravity = 9.8f) {
    float radAngle = angle * M_PI / 180.0f;
    player.x += initialVelocity * cos(radAngle) * player.time;
    player.y -= (initialVelocity * sin(radAngle) * player.time - 0.5f * gravity * player.time * player.time);
    player.time += 0.1f;
}

// Ελλειπτική κίνηση με σταθερή ταχύτητα
void ellipticalMotion(Player& player, float centerX, float centerY, float a, float b, float speed) {
    player.angle += speed;
    player.x = centerX + a * cos(player.angle * M_PI / 180.0f);
    player.y = centerY + b * sin(player.angle * M_PI / 180.0f);
}

// Σχεδίαση του παίκτη ως κύκλου
void drawPlayer(const Player& player) {
    graphics::Brush brush;
    brush.fill_color[0] = 0.0f;
    brush.fill_color[1] = 0.0f;
    brush.fill_color[2] = 1.0f;
    graphics::drawDisk(player.x, player.y, player.radius, brush);
}

// Επαναφορά του χρόνου
void resetTime(Player& player) {
    player.time = 0.0f;
}

#endif // PLAYER_ORBIT_GR_H

