#include "Player_orbit.h"
#include "sgg/graphics.h"
#include <iostream>

// Ρυθμίσεις παραθύρου
const float WINDOW_WIDTH = 800.0f;
const float WINDOW_HEIGHT = 600.0f;

// Αρχικοποίηση του παίκτη
Player player = { WINDOW_WIDTH / 2, WINDOW_HEIGHT / 2, 15.0f, 2.0f, 0.0f, 0.0f };
int movementType = 0; // Τύπος κίνησης

// Συνάρτηση σχεδίασης
void draw() {
    // Καθαρισμός παραθύρου
    graphics::Brush bgBrush;
    bgBrush.fill_color[0] = 1.0f;
    bgBrush.fill_color[1] = 1.0f;
    bgBrush.fill_color[2] = 1.0f;
    graphics::drawRect(WINDOW_WIDTH / 2, WINDOW_HEIGHT / 2, WINDOW_WIDTH, WINDOW_HEIGHT, bgBrush);

    // Σχεδίαση του παίκτη
    drawPlayer(player);
}

// Συνάρτηση ενημέρωσης για τη μετακίνηση του παίκτη
void update(float ms) {
    if (graphics::getKeyState(graphics::SCANCODE_RIGHT)) movementType = 1;
    if (graphics::getKeyState(graphics::SCANCODE_LEFT)) movementType = 2;
    if (graphics::getKeyState(graphics::SCANCODE_UP)) movementType = 3;
    if (graphics::getKeyState(graphics::SCANCODE_DOWN)) movementType = 4;
    if (graphics::getKeyState(graphics::SCANCODE_SPACE)) movementType = 5;
    if (graphics::getKeyState(graphics::SCANCODE_LSHIFT)) movementType = 6;
    if (graphics::getKeyState(graphics::SCANCODE_TAB)) movementType = 7;

    // Ανάλογα με τον τύπο κίνησης, καλείται η αντίστοιχη συνάρτηση
    switch (movementType) {
    case 1:
        moveHorizontal(player, player.speed);
        break;
    case 2:
        moveVertical(player, player.speed);
        break;
    case 3:
        moveCircular(player, WINDOW_WIDTH / 2, WINDOW_HEIGHT / 2, 100, 1.0f);
        break;
    case 4:
        freeFall(player);
        break;
    case 5:
        verticalThrow(player, 20.0f);
        break;
    case 6:
        inclinedThrow(player, 20.0f, 45.0f);
        break;
    case 7:
        ellipticalMotion(player, WINDOW_WIDTH / 2, WINDOW_HEIGHT / 2, 150, 100, 1.0f);
        break;
    }

    // Επαναφορά του παίκτη αν υπερβεί τα όρια
    if (player.x < 0 || player.x > WINDOW_WIDTH || player.y < 0 || player.y > WINDOW_HEIGHT) {
        player.x = WINDOW_WIDTH / 2;
        player.y = WINDOW_HEIGHT / 2;
        resetTime(player); // Επαναφορά του χρόνου για ελεύθερη πτώση/βολή
    }
}

int main() {
    // Δημιουργία παραθύρου
    graphics::createWindow(WINDOW_WIDTH, WINDOW_HEIGHT, "Player's Movements");

    // Ορισμός συνάρτησης σχεδίασης και ενημέρωσης
    graphics::setDrawFunction(draw);
    graphics::setUpdateFunction(update);

    // Έναρξη κύκλου μηνυμάτων
    graphics::startMessageLoop();

    return 0;
}